scripts/uninstall-debugclients.py

changeset 7960
e8fc383322f7
parent 7923
91e843545d9a
child 8243
cc717c2ae956
diff -r 44e15eda6506 -r e8fc383322f7 scripts/uninstall-debugclients.py
--- a/scripts/uninstall-debugclients.py	Tue Jan 05 18:28:31 2021 +0100
+++ b/scripts/uninstall-debugclients.py	Wed Jan 06 13:47:01 2021 +0100
@@ -3,11 +3,11 @@
 
 # Copyright (c) 2016 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 # This is the uninstall script for the eric6 debug client.
 #
 
 """
-Unnstallation script for the eric6 debug clients.
+Unnstallation script for the eric debug clients.
 """
 
 import sys
@@ -109,7 +109,7 @@
         if opt in ["-h", "--help"]:
             usage(0)
     
-    print("\nUninstalling eric6 debug clients ...")
+    print("\nUninstalling eric debug clients ...")
     uninstallEricDebugClients()
     print("\nUninstallation complete.")
     print()
@@ -3,11 +3,11 @@
 # Copyright (c) 2016 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
-# This is the uninstall script for the eric6 debug client.
+# This is the uninstall script for the eric debug client.
 #
 

eric ide

mercurial